@@ -344,11 +344,7 @@ static void create_track_clist(void) {
 	gtk_clist_column_titles_show(GTK_CLIST(audio_clist));
 	gtk_clist_set_column_justification(GTK_CLIST(audio_clist), 0, GTK_JUSTIFY_LEFT);
 	gtk_clist_set_column_justification(GTK_CLIST(audio_clist), 1, GTK_JUSTIFY_RIGHT); 
-/*
-	gtk_signal_connect_after(GTK_OBJECT(mainwindow), "configure_event",
-			GTK_SIGNAL_FUNC(resize_clist_col_ratio),
-			GTK_WIDGET(audio_clist));
-*/
+
 	gtk_clist_set_column_auto_resize(GTK_CLIST(audio_clist), 0, TRUE);
 
 	gtk_signal_connect(GTK_OBJECT(audio_clist), "select_row",
@@ -390,7 +386,7 @@ static void dropped_audio(GtkWidget *widget, GdkDragContext *context, gint x, gi
 				return;
 		}
 
-		cursor_wait(NULL);
+		cursor_wait();
 		mainwindow_disable_tabs();
 		while (names) {
 			add_track(0, (gchar *) names->data);
@@ -399,7 +395,7 @@ static void dropped_audio(GtkWidget *widget, GdkDragContext *context, gint x, gi
 		}
 		mainwindow_enable_tabs();
 		gnome_uri_list_free_strings(list);
-		cursor_reset(NULL);
+		cursor_reset();
 	} else {
 		g_message("%s %i: unknown type dropped, should not happen!",
 				__FILE__, __LINE__);
