@@ -454,7 +454,7 @@ void print_cmd_callback(GtkWidget *widget, gpointer data) {
 	gtk_widget_show(hbox8);
 	gtk_box_pack_start(GTK_BOX(vbox1), hbox8, FALSE, FALSE, 0);
 
-	subcatecory_label = gtk_label_new(_("Subcategory:"));
+	subcatecory_label = gtk_label_new(_("Sub-category:"));
 	gtk_widget_show(subcatecory_label);
 	gtk_box_pack_start(GTK_BOX(hbox8), subcatecory_label, FALSE, FALSE, 0);
 
@@ -495,16 +495,16 @@ void print_cmd_callback(GtkWidget *widget, gpointer data) {
 	gtk_widget_show(no_plaque);
 	gtk_box_pack_start(GTK_BOX(hbox8), no_plaque, FALSE, FALSE, 0);
 	gtk_tooltips_set_tip(tooltips, no_plaque, _(
-				"Suppresses printing of the Plaque (the category/subcategory banner)"
-				"on the traycard, "
-				"thus allowing you to fit even more items on the traycard."
+				"Suppresses printing of the Plaque (the category/sub-category banner)"
+				"on the tray card, "
+				"thus allowing you to fit even more items on the tray card."
 				"(needs cdlabelgen 1.5 or newer)"), NULL);
 
 	word_wrap = gtk_check_button_new_with_label(_("Enable word wrapping"));
 	gtk_widget_show(word_wrap);
 	gtk_box_pack_start(GTK_BOX(hbox8), word_wrap, FALSE, FALSE, 0);
 	gtk_tooltips_set_tip(tooltips, word_wrap, _(
-				"Enables word wrapping of the items that print on the traycard."
+				"Enables word wrapping of the items that print on the tray card."
 				"(needs cdlabelgen 1.5 or newer)"), NULL);
 
 	/* */
@@ -519,7 +519,7 @@ void print_cmd_callback(GtkWidget *widget, gpointer data) {
 	gtk_widget_show(hbox8);
 	gtk_box_pack_start(GTK_BOX(vbox1), hbox8, FALSE, FALSE, 0);
 
-	use_eps = gtk_check_button_new_with_label(_("Cover eps file"));
+	use_eps = gtk_check_button_new_with_label(_("Cover EPS file"));
 	gtk_widget_show(use_eps);
 	gtk_box_pack_start(GTK_BOX(hbox8), use_eps, FALSE, FALSE, 0);
 	gtk_tooltips_set_tip(tooltips, use_eps,
@@ -533,7 +533,7 @@ void print_cmd_callback(GtkWidget *widget, gpointer data) {
 	gtk_box_pack_end(GTK_BOX(hbox8), eps_scale, FALSE, FALSE, 0);
 	gtk_tooltips_set_tip(tooltips, eps_scale,
 			_("The ratio by which you "
-			"want to scale the epsfile that appears on the cover"), NULL);
+			"want to scale the EPS file that appears on the cover"), NULL);
 	gtk_entry_set_text(GTK_ENTRY(eps_scale), "1");
 
 	label = gtk_label_new(_("Scale:"));
@@ -566,7 +566,7 @@ void print_cmd_callback(GtkWidget *widget, gpointer data) {
 	gtk_widget_show(use_tray);
 	gtk_box_pack_start(GTK_BOX(hbox8), use_tray, FALSE, FALSE, 0);
 	gtk_tooltips_set_tip(tooltips, use_tray,
-			_("Add an EPS (Encapsulated PostScript) file to the traycard"),
+			_("Add an EPS (Encapsulated PostScript) file to the tray card"),
 			NULL);
 	gtk_signal_connect(GTK_OBJECT(use_tray), "button_release_event",
 			GTK_SIGNAL_FUNC(tray_in_use), 0);
@@ -576,7 +576,7 @@ void print_cmd_callback(GtkWidget *widget, gpointer data) {
 	gtk_box_pack_end(GTK_BOX(hbox8), tray_scale, FALSE, FALSE, 0);
 	gtk_tooltips_set_tip(tooltips, tray_scale,
 			_("The ratio by which you want "
-			"to scale the epsfile that appears on the traycard"), NULL);
+			"to scale the EPS file that appears on the tray card"), NULL);
 	gtk_entry_set_text(GTK_ENTRY(tray_scale), "1");
 
 	label = gtk_label_new(_("Scale:"));
@@ -593,13 +593,13 @@ void print_cmd_callback(GtkWidget *widget, gpointer data) {
 	gtk_signal_connect(GTK_OBJECT(tray_select_file), "clicked",
 			GTK_SIGNAL_FUNC(choose_file), (gpointer) path_for_tray_file);
 	gtk_tooltips_set_tip(tooltips, tray_select_file,
-			_("Select traycard EPS file"), NULL);
+			_("Select tray card EPS file"), NULL);
 
 	tray_filename = gtk_entry_new();
 	gtk_widget_show(tray_filename);
 	gtk_box_pack_start(GTK_BOX(hbox8), tray_filename, TRUE, TRUE, 0);
 	gtk_tooltips_set_tip(tooltips, tray_filename,
-			_("Path to traycard EPS file"), NULL);
+			_("Path to tray card EPS file"), NULL);
 	/* */
 	frame = make_frame(_("Make cover"), 3);
         gtk_box_pack_start(GTK_BOX(vbox7), frame, FALSE, FALSE, 0);
