@@ -41,15 +41,15 @@
 #include "globals.h"
 
 GtkWidget *dummy, *eject, *pad, *swab_audio, *dao, *no_image, *use_image;
-GtkWidget *audio_tracks, *image_path;
+GtkWidget *audio_tracks, *image_path, *overburn;
 GtkWidget *copy_iso_cd, *iso_device_path, *copy_audio_cd, *audio_device_path;
 GtkWidget *blank_all, *blank_fast, *fsentry, *need_track_size, *enable_burnproof;
-GtkWidget *speed_spin, *disable_fixate;
+GtkWidget *speed_spin, *grace_time_spin, *disable_fixate;
 char *def_image_path = NULL;
 
 /* TODO: this file is getting too large and covers to much stuff - split it */
 
-static GtkWidget *make_image, *read_image;
+static GtkWidget *make_image, *read_image, *image_verbose_info_button;
 
 static void generate_image(GtkWidget *widget, gpointer data) {
 	cmd_v *mkisofs;
@@ -92,10 +92,12 @@ static void generate_image(GtkWidget *widget, gpointer data) {
 static void can_make_image(GtkWidget *widget, gpointer *data) {
 	gtk_widget_set_sensitive(make_image, TRUE);
 	gtk_widget_set_sensitive(read_image, TRUE);
+	gtk_widget_set_sensitive(image_verbose_info_button, TRUE);
 }
 static void cannot_make_image(GtkWidget *widget, gpointer *data) {
 	gtk_widget_set_sensitive(make_image, FALSE);
 	gtk_widget_set_sensitive(read_image, FALSE);
+	gtk_widget_set_sensitive(image_verbose_info_button, FALSE);
 }
 
 static void selected_image_dir(GtkWidget *widget, gpointer data) {
@@ -181,7 +183,7 @@ static void image_selection(GtkWidget *vbox1, config_cdr_data *cdr_info) {
 	make_image = gtk_button_new_with_label(_("Create image from files"));
 	gtk_widget_show(make_image);
 	gtk_box_pack_end(GTK_BOX(hbox), make_image, FALSE, TRUE, 0);
-	gtk_tooltips_set_tip(tooltips, make_image, _("Make the iso-image to be burned from Data Files"), NULL);
+	gtk_tooltips_set_tip(tooltips, make_image, _("Make the ISO-image to be burned from Data Files"), NULL);
 	gtk_signal_connect(GTK_OBJECT(make_image),
 			"clicked", (GtkSignalFunc) generate_image, cdr_info);
 	gtk_widget_set_sensitive(make_image, FALSE);
@@ -189,16 +191,25 @@ static void image_selection(GtkWidget *vbox1, config_cdr_data *cdr_info) {
 	read_image = gtk_button_new_with_label(_("Read image from CD"));
 	gtk_widget_show(read_image);
 	gtk_box_pack_end(GTK_BOX(hbox), read_image, FALSE, TRUE, 0);
-	gtk_tooltips_set_tip(tooltips, read_image, _("Read the iso-image to be burned from "
+	gtk_tooltips_set_tip(tooltips, read_image, _("Read the ISO-image to be burned from "
 				"an existing CD-ROM. The image is read from the device "
 				"specified in the existing ISO 9660 field below. Some (all?) "
-				"IDE burners used with the scsi emulation layer has problems "
+				"IDE burners used with the SCSI emulation layer has problems "
 				"with this. Encountering an error the routine will retry 20 "
 				"times before giving up."), NULL);
 	gtk_signal_connect(GTK_OBJECT(read_image),
 			"clicked", (GtkSignalFunc) read_image_from_cd, cdr_info);
 	gtk_widget_set_sensitive(read_image, FALSE);
 
+	image_verbose_info_button = gtk_button_new_with_label(_("Info"));
+	gtk_widget_show(image_verbose_info_button);
+	gtk_box_pack_end(GTK_BOX(hbox), image_verbose_info_button, FALSE, TRUE, 0);
+	gtk_tooltips_set_tip(tooltips, image_verbose_info_button,
+			_("Displays verbose information about the ISO 9660 image"), NULL);
+	gtk_signal_connect(GTK_OBJECT(image_verbose_info_button),
+			"clicked", (GtkSignalFunc) verbose_info_clicked, GINT_TO_POINTER(0));
+	gtk_widget_set_sensitive(image_verbose_info_button, FALSE);
+
 /* copy */
 
 	hbox = gtk_hbox_new(FALSE, 0);
@@ -228,7 +239,7 @@ static void image_selection(GtkWidget *vbox1, config_cdr_data *cdr_info) {
 	gtk_tooltips_set_tip(tooltips, verbose_info_button,
 			_("Displays verbose information about the ISO 9660 CD"), NULL);
 	gtk_signal_connect(GTK_OBJECT(verbose_info_button),
-			"clicked", (GtkSignalFunc) verbose_info_clicked, NULL);
+			"clicked", (GtkSignalFunc) verbose_info_clicked, GINT_TO_POINTER(1));
 
 /* audio tracks */
 
@@ -290,7 +301,7 @@ GtkWidget *select_speed(GtkWidget *hbox) {
 	GtkWidget *speed_label, *spinbutton;
 	GtkObject *spinbutton_adj;
 
-	speed_label = gtk_label_new(_("Select speed:"));
+	speed_label = gtk_label_new(_("Speed:"));
 	gtk_widget_show(speed_label);
 	gtk_box_pack_start(GTK_BOX(hbox), speed_label, FALSE, TRUE, 0);
 
@@ -302,6 +313,27 @@ GtkWidget *select_speed(GtkWidget *hbox) {
 	return spinbutton;
 }
 
+GtkWidget *select_grace_time(GtkWidget *hbox) {
+	GtkWidget *label, *spinbutton;
+	GtkObject *spinbutton_adj;
+
+	label = gtk_label_new(_("Grace time:"));
+	gtk_widget_show(label);
+	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, TRUE, 0);
+
+	spinbutton_adj = gtk_adjustment_new(9, 2, 100, 1, 10, 10);
+	spinbutton = gtk_spin_button_new(GTK_ADJUSTMENT(spinbutton_adj), 1, 0);
+	gtk_tooltips_set_tip(tooltips, spinbutton,
+			_("Set the grace time before starting the write (the "
+				"default is 9 seconds, keep it at that if your "
+				"cdrecord version does not understand this option)"),
+			NULL);
+	gtk_widget_show(spinbutton);
+	gtk_box_pack_start(GTK_BOX(hbox), spinbutton, FALSE, TRUE, 0);
+
+	return spinbutton;
+}
+
 static void record_options(GtkWidget *vbox1, config_cdr_data *cdr_info) {
 	GtkWidget *hbox1, *hbox4, *frame, *vbox, *hbox2, *fslabel;
 
@@ -319,6 +351,9 @@ static void record_options(GtkWidget *vbox1, config_cdr_data *cdr_info) {
 	speed_spin = select_speed(hbox1);
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(speed_spin), 2);
 
+	grace_time_spin = select_grace_time(hbox1);
+	gtk_spin_button_set_value(GTK_SPIN_BUTTON(grace_time_spin), 9);
+
 	hbox2 = gtk_hbox_new(FALSE, 0);
 	gtk_widget_show(hbox2);
 	gtk_box_pack_start(GTK_BOX(hbox1), hbox2, TRUE, TRUE, 0);
@@ -329,10 +364,10 @@ static void record_options(GtkWidget *vbox1, config_cdr_data *cdr_info) {
 	fslabel = gtk_label_new(_("FIFO size: "));
 	gtk_widget_show(fslabel);
 	gtk_box_pack_end(GTK_BOX(hbox2), fslabel, FALSE, FALSE, 0);
-	gtk_tooltips_set_tip(tooltips, fsentry, _("Set the fifo size (default "
+	gtk_tooltips_set_tip(tooltips, fsentry, _("Set the FIFO size (default "
 				"is 4 MB, and it will be used if nothing is specified) - goes "
 				"directly to the cdrecord fs= option so the syntax is the same "
-				"as cdrecords (e.g. 10x53k == 630 kBytes)"), NULL);
+				"as cdrecord's (e.g. 10x53k == 630 kBytes)"), NULL);
 	cdr_info->fifo = fsentry;
 
 	hbox4 = gtk_hbox_new(FALSE, 0);
@@ -345,7 +380,8 @@ static void record_options(GtkWidget *vbox1, config_cdr_data *cdr_info) {
 	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(dummy), TRUE);
 	gtk_tooltips_set_tip(tooltips, dummy, _("Go through every step of the "
 				"recording process, but leave the laser off - good way to make "
-				"sure everything is ok and that the system can cope with the load."),
+				"sure everything is OK and that the system can cope with the load. "
+				"(See File/Preferences if you don't want this enabled by default)."),
 			NULL);
 
 	eject = gtk_check_button_new_with_label(_("Eject target when done"));
@@ -360,7 +396,7 @@ static void record_options(GtkWidget *vbox1, config_cdr_data *cdr_info) {
 	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(pad), TRUE);
 	gtk_tooltips_set_tip(tooltips, pad, _("For data tracks: Usable if your drive can't read the "
 			"last sectors of a track or if you want to be able to read the CD on an old "
-			"Linux system with the ISO 9660 filesystem read ahead bug. For audio tracks: "
+			"Linux system with the ISO 9660 file system read ahead bug. For audio tracks: "
 			"All audio data to be a multiple of 2352 bytes (as it should be). It's safest to "
 			"leave this on, especially for audio tracks."), NULL);
 
@@ -377,6 +413,14 @@ static void record_options(GtkWidget *vbox1, config_cdr_data *cdr_info) {
 	gtk_tooltips_set_tip(tooltips, swab_audio, _("Assume audio data is in byte-swapped "
 			"(little-endian) order"), NULL);
 
+	overburn = gtk_check_button_new_with_label(_("overburn"));
+	gtk_widget_show(overburn);
+	gtk_box_pack_start(GTK_BOX(hbox4), overburn, FALSE, TRUE, 0);
+	gtk_tooltips_set_tip(tooltips, overburn,
+			_("Allow cdrecord to write more than the official size of a medium. "
+			"Most CD recorders only do overburning in DAO mode, and there is no "
+			"guarantee that your drive supports overburning at all."), NULL);
+
 	/* start a new row... TODO: this would really look better with a table */
 	hbox4 = gtk_hbox_new(FALSE, 0);
 	gtk_widget_show(hbox4);
@@ -515,12 +559,14 @@ static void start_burning(GtkWidget *widget, gpointer data) {
 		struct stat buf;
 		char *p = gtk_entry_get_text(GTK_ENTRY(image_path));
 		if (0 != stat(p, &buf)) {
-			g_warning("%s::%i: error stat():ing the image to be burned (%s), "
-					"continuing anyway", __FILE__, __LINE__, p);
-			/* FIXME: take action? */
+			char *s;
+			s = g_strdup_printf(_("Error accessing the image file (%s), it does not seem to exist."), p);
+			alert_user_of_error(s);
+			g_free(s);
+			return;
 		} else if ((buf.st_mode & S_IFMT) == S_IFDIR) {
 			alert_user_of_error(_("You are trying to burn a directory, "
-						"please fill in the full path/imagename in the "
+						"please fill in the full path/image name in the "
 						"image location field."));
 			return;
 		}
