@@ -18,10 +18,11 @@
 
 config_cdr_data *create_cdrecord_options(GtkWidget *);
 GtkWidget *select_speed(GtkWidget *);
+GtkWidget *select_grace_time(GtkWidget *);
 
 extern GtkWidget *dummy, *eject, *pad, *swab_audio, *dao, *no_image, *use_image, *audio_tracks;
 extern GtkWidget *audio_tracks_combo, *image_path, *copy_iso_cd, *iso_device_path, *copy_audio_cd;
-extern GtkWidget *blank_all, *blank_fast, *audio_device_path, *disable_fixate;
-extern GtkWidget *fsentry, *need_track_size, *enable_burnproof, *speed_spin;
+extern GtkWidget *blank_all, *blank_fast, *audio_device_path, *disable_fixate, *overburn;
+extern GtkWidget *fsentry, *need_track_size, *enable_burnproof, *speed_spin, *grace_time_spin;
 extern char *def_image_path;
 
