@@ -131,8 +131,10 @@ static cmd_v *make_cdrecord_common(config_cdr_data *cdr_info, int can_eject) {
 
 	add_option_to_cmd(cdr_cmd, "-v");
 
-	if (GTK_TOGGLE_BUTTON(dummy)->active)
+	if (GTK_TOGGLE_BUTTON(dummy)->active) {
+		alert_user_of_error(_("Please note that you have the dummy option enabled: you are starting a test run."));
 		add_option_to_cmd(cdr_cmd, "-dummy");
+	}
 	if (can_eject && GTK_TOGGLE_BUTTON(eject)->active)
 		add_option_to_cmd(cdr_cmd, "-eject");
 	if (GTK_TOGGLE_BUTTON(pad)->active)
@@ -142,10 +144,18 @@ static cmd_v *make_cdrecord_common(config_cdr_data *cdr_info, int can_eject) {
 	add_option_to_cmd(cdr_cmd, tmp_text);
 	free(tmp_text);
 
+	if (9 != gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(grace_time_spin))) {
+		tmp_text = g_strdup_printf("gracetime=%i", gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(grace_time_spin)));
+		add_option_to_cmd(cdr_cmd, tmp_text);
+		free(tmp_text);
+	}
+
 	make_cdrecord_device(cdr_cmd, cdr_info);
 
 	if (GTK_TOGGLE_BUTTON(dao)->active)
 		add_option_to_cmd(cdr_cmd, "-dao");
+	if (GTK_TOGGLE_BUTTON(overburn)->active)
+		add_option_to_cmd(cdr_cmd, "-overburn");
 	if ((strcmp((tmp_text = gtk_entry_get_text(GTK_ENTRY(fsentry))), ""))) {
 		char *fs;
 		fs = string_append("fs=", NULL);
@@ -201,7 +211,7 @@ cmd_v *make_cdrecord_command(config_cdr_data *cdr_info) {
 	if (GTK_TOGGLE_BUTTON(use_image)->active) {
 		if (!(strcmp((tmp = gtk_entry_get_text(GTK_ENTRY(image_path))), ""))) {
 			alert_user_of_error(_("No image is selected, but the use image"
-						"button is checked.\n Please select an image."));
+						" button is checked.\n Please select an image."));
 			destroy_cmd(cdr_cmd);
 			return NULL;
 		}	
@@ -223,7 +233,7 @@ cmd_v *make_cdrecord_command(config_cdr_data *cdr_info) {
 				return NULL;
 			}
 			tmp = string_append("tsize=", NULL);
-			if (-1 == g_snprintf(tsize, 10, "%li", sectorsize)) {
+			if (-1 == g_snprintf(tsize, 10, "%lli", sectorsize)) {
 				g_warning("%s::%i: size buffer too small!", __FILE__, __LINE__);
 				destroy_cmd(cdr_cmd);
 				return NULL;
@@ -237,7 +247,7 @@ cmd_v *make_cdrecord_command(config_cdr_data *cdr_info) {
 	} else if (GTK_TOGGLE_BUTTON(copy_iso_cd)->active) {
 		if (!(strcmp((tmp = gtk_entry_get_text(GTK_ENTRY(iso_device_path))), ""))) {
 			alert_user_of_error(_("No in-device entered, but the copy existing ISO 9660"
-						"cd option is enabled.\n Please enter a valid device."));
+						"CD option is enabled.\n Please enter a valid device."));
 			destroy_cmd(cdr_cmd);
 			return NULL;
 		}
@@ -437,6 +447,13 @@ static cmd_v *make_mkisofs_c_options(int printsize) {
 		if (GTK_TOGGLE_BUTTON(mkhybrid_options[i].widget)->active)
 			add_option_to_cmd(cmd, mkhybrid_options[i].cmd_line);
 	}
+	if (GTK_TOGGLE_BUTTON(mkhybrid_options[0].widget)->active || GTK_TOGGLE_BUTTON(mkhybrid_options[1].widget)->active) {
+		tmp = gtk_entry_get_text(GTK_ENTRY(mkhybrid_text_options[0].widget));
+		if (strlen(tmp) != 0) {
+			add_option_to_cmd(cmd, mkhybrid_text_options[0].cmd_line);
+			add_option_to_cmd(cmd, tmp);
+		}
+	}
 
 	add_extra_mkisofs_options(cmd);
 
@@ -583,10 +600,8 @@ cmd_v *make_mkisofs_c_optimize(file_data *check_these[], int no_of_selections) {
 	char *tmp2;
 	int j;
 
-	if (0 == GTK_CLIST(clist)->rows) {
-		alert_user_of_error(_("No files selected"));
+	if (0 == no_of_selections)
 		return NULL;
-	}
 
 	cmd = make_mkisofs_c_options(TRUE);
 
