@@ -125,9 +125,9 @@ void cdrecord_checkdrive(GtkWidget *widget, gpointer data) {
 
 	if (do_cdrecord_shortcommand(" -checkdrive", cdr_info))
 		label = gtk_label_new(_("cdrecord failed to recognize selected drive\n"
-					"(wrong scsi settings or no permission to device)!"));
+					"(wrong SCSI settings or no permission to device)!"));
 	else
-		label = gtk_label_new(_("    Settings ok!    "));
+		label = gtk_label_new(_("    Settings OK!    "));
 
 	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog_window)->vbox), label, TRUE,
 			TRUE, 10);
@@ -232,7 +232,7 @@ void cdrecord_reset_drive(GtkWidget *widget, gpointer data) {
 
 	if (do_cdrecord_shortcommand(" -reset", cdr_info))
 		label = gtk_label_new(_("cdrecord failed to reset selected drive\n"
-					"(wrong scsi settings, no permission to device or\n"
+					"(wrong SCSI settings, no permission to device or\n"
 					"the device did not accept the reset sequence)!"));
 	else
 		label = gtk_label_new(_("Device successfully reset"));
