@@ -41,7 +41,6 @@ void exit_program(void);
 /* functions by which the code file- and structurewise is split */
 
 void create_options(GtkWidget *);
-void read_mkisofs_output(gpointer, gint, GdkInputCondition);
 void open_mkisofs_progress_bar(int *);
 void open_cdrecord_progress_bar(int *);
 void open_mkisofs_cdrecord_progress_bar(int *);
@@ -61,6 +60,7 @@ extern options mkisofs_options[];
 extern options mkisofs_special_options[];
 extern options mkisofs_text_options[];
 extern options mkhybrid_options[];
+extern options mkhybrid_text_options[];
 extern options torito_options[];
 
 extern int m_o_length;
