@@ -52,8 +52,8 @@ static GtkItemFactoryEntry menu_items[] =
 	{N_("/File/_Print cover"), "<control>P", print_cmd_callback, 0, NULL},
 	{N_("/File/P_references..."), "<control>R", preferences_cmd_callback, 0, NULL},
 	{N_("/File/sep"), NULL, NULL, 0, "<Separator>"},
-	{N_("/File/_Eject cd-r"), "<control>E", trayaction_cmd_callback, TRAY_EJECT, NULL},
-	{N_("/File/_Close cd-r"), "<control>C", trayaction_cmd_callback, TRAY_CLOSE, NULL},
+	{N_("/File/_Eject CD-R"), "<control>E", trayaction_cmd_callback, TRAY_EJECT, NULL},
+	{N_("/File/_Close CD-R"), "<control>C", trayaction_cmd_callback, TRAY_CLOSE, NULL},
 	{N_("/File/sep"), NULL, NULL, 0, "<Separator>"},
 	{N_("/File/_Quit"), "<control>Q", quit_cmd_callback, 0, NULL},
 	{N_("/File selection"), NULL, NULL, 0, "<Branch>"},
@@ -74,7 +74,7 @@ static GtkItemFactoryEntry menu_items[] =
 };
 
 static void call_load_selection(GtkWidget *widget, gpointer data) {
-	load_selection(gtk_file_selection_get_filename(data));
+	load_selection(gtk_file_selection_get_filename(GTK_FILE_SELECTION(data)));
 	gtk_widget_destroy(GTK_WIDGET(data));
 }
 
@@ -163,7 +163,7 @@ static void about_cmd_callback(GtkWidget *widget, gpointer data) {
 	about_win = gtk_dialog_new();
 	gtk_widget_show(about_win);
 
-	info_text = g_strdup_printf("gcombust version %s\n(c) 1999, 2000, 2001 Jonas Munsin <jmunsin@iki.fi>\nReleased under GPL.\n\n I plan to graduate soon.\n Interesting and/or well-paid job offers are welcome ;-) \n CV at http://www.iki.fi/jmunsin/CV.eng  ", VERSION);
+	info_text = g_strdup_printf("gcombust version %s\n(c) 1999, 2000, 2001, 2002 Jonas Munsin <jmunsin@iki.fi>\nReleased under GPL.\n\n Interesting and/or well-paid job offers are welcome ;-) \n CV at http://www.iki.fi/jmunsin/CV.eng  ", VERSION);
 	label = gtk_label_new(info_text);
 	g_free(info_text);
 
