@@ -37,7 +37,7 @@
 
 /* static gint sel_row_path = -1; */
 static long int lastsize = 0;
-static char *dir_base = NULL;
+static GList *file_path_list, *dir_path_list;
 
 static void update_totalsize_label(void) {
 	char *sizeinfolabel;
@@ -91,7 +91,7 @@ static void error_when_executing(cmd_v *command, const char *error_details, char
 	char *cmd_string, *error_msg;
 
 	cmd_string = cmd_to_string(command);
-	error_msg = g_strdup_printf(_("%s\n\n The following command was executed when the error occured: \n%s"), error_details, cmd_string);
+	error_msg = g_strdup_printf(_("%s\n\n The following command was executed when the error occurred: \n%s"), error_details, cmd_string);
 
 	if (NULL == output)
 		alert_user_of_error(error_msg);
@@ -116,8 +116,8 @@ static struct {
 			" estimate might be a little bit wrong), "
 			"add more files before burning ")},
 	{"Unable to sort directory ", N_(" mkisofs failed to sort directory, "
-			"(maybe a problem with multisession, \n try "
-			"enabeling the No RR option if multisession "
+			"(maybe a problem with multi session, \n try "
+			"enabling the No RR option if multi session "
 			"is used). It it also possible \n that there "
 			"is a duplicate filename in the list, if so, "
 			"please rename it. \n It is also quite "
@@ -248,29 +248,95 @@ static int path_is_in_iso(char *path) {
 	for (i = 0; i < GTK_CLIST(clist)->rows; i ++) {
 		info = gtk_clist_get_row_data(GTK_CLIST(clist), i);
 		g_assert(NULL != info);
-		if (strlen(path) == strlen(info->realpath) && (!(strncmp(path, info->realpath, strlen(path)))))
+		if (!strcmp(path, info->realpath))
 			return TRUE;
 	}
 	return FALSE;
 }
 
-static void add_path_to_iso_files(gpointer data, gpointer user_data) {
+static char *my_basename_n_r(char *path, int level) {
+	int i;
+
+	if (0 == level)
+		return &path[1];
+
+	for (i = strlen(path)-1; i > 0; i--) {
+		if ('/' == path[i])
+			level--;
+		if (0 == level)
+			return &path[i+1];
+	}
+	return &path[1];
+}
+
+static char *my_basename_n(char *path, int level) {
+	unsigned int i;
+
+	if (0 == level)
+		return &path[1];
+
+	for (i = 1; i < strlen(path); i++) {
+		if ('/' == path[i])
+			level--;
+		if (0 == level)
+			return &path[i+1];
+	}
+	return my_basename(path);
+}
+
+
+/* path: a normal path, eg /usr/bin/mkisofs (note: it will be modified)
+ * level: how many path components to include in the path
+ *   if direction == 1:
+ *        1: the "normal" (include one component, eg
+ *           /usr/bin/mkisofs => mkisofs, /usr/bin/ => bin/
+ *        2: /usr/bin/mkisofs => bin/mkisofs, /usr/bin/ => usr/bin/
+ *        3: /usr/bin/mkisofs => usr/bin/mkisofs, /usr/bin/ => usr/bin/
+ *        ...etc
+ *        0: include all (ie treat as infinity, eg same as 3 above)
+ *   if direction == 0:
+ *        0: include all
+ *        1: ignore top level, eg
+ *           /usr/bin/mkisofs => bin/mkisofs, /usr/bin/ => usr/bin/
+ *        2: ignore two topmost levels, eg
+ *           /usr/bin/mkisofs => mkisofs, /usr/bin/ => bin/
+ *        3: /usr/bin/mkisofs => mkisofs, /usr/bin/ => bin/
+ *        (eg prevent empty filenames)
+ */
+static char *get_user(char *path, int level, int direction) {
+	char *ret;
+	int trailing_slash;
+
+	trailing_slash = path[strlen(path)-1] == '/';
+
+	my_strip_trailing_slashes(path);
+
+	if (1 == direction)
+		ret = g_strdup(my_basename_n_r(path, level));
+	else
+		ret = g_strdup(my_basename_n(path, level));
+
+	/* there may be a mkisofs bug / windows bug that causes strange
+	 * behaviour when directories end with slashes, but for now at least
+	 * they are still preserved (hey, it looks better :) */
+	if (trailing_slash) {
+		char *tmp;
+		tmp = ret;
+		ret = g_strdup_printf("%s/", ret);
+		g_free(tmp);
+	}
+
+	return ret;
+}
+
+static void add_path_to_iso_files(gpointer data) {
 	cmd_v *exec_string;
-	char tmp_buf[SIZE_BUF_SIZE];
 	char *text[2];
 	int newrow;
 	file_data *info;
 	char *path;
 
-	/* extract path */
-	if (NULL == user_data)
-		path = strdup(data);
-	else {
-		char *tmp;
-		gtk_clist_get_text(user_data, GPOINTER_TO_INT(data), 0, &tmp);
-		path = string_append(dir_base, NULL);
-		path = string_append(path, tmp);
-	}
+	path = strdup(data);
 	if (path_is_in_iso(path)) {
 		alert_user_of_error(_("You tried to add a duplicate file/dir to the file list!"));
 		free(path);
@@ -294,95 +360,133 @@ static void add_path_to_iso_files(gpointer data, gpointer user_data) {
 	}
 	destroy_cmd(exec_string);
 
-	if (g_snprintf(tmp_buf, SIZE_BUF_SIZE, "%.1f",
-			(double)lastsize*2048/(1024*1024)) == -1)
-		g_warning("%s::%i: file size too large? Size-result is probably wrong", __FILE__, __LINE__);
-	text[1] = tmp_buf;
-
 	info = malloc(sizeof(file_data));
 	info->size = lastsize;
 
-	/* this might seem a bit too compact, but attempts to make it more readable
-	 * resulted in longer and harder to trace trough code */
-	if (path[strlen(path)-1] == '/') {
-		my_strip_trailing_slashes(path);
-		text[0] = my_basename(path);
-		info->realpath = g_strdup_printf("%s/", path);
-		info->userpath = g_strdup_printf("%s/", my_basename(path));
-		path[strlen(path)] = '/';
-	} else {
-		text[0] = my_basename(path);
-		info->realpath = g_strdup(path);
-		info->userpath = g_strdup(my_basename(path));
-	}
+	info->realpath = g_strdup(path);
+	info->userpath = get_user(path,
+			gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(path_default_level_sb)),
+			gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(path_default_from_end)));
+
+	text[0] = info->userpath;
+	text[1] = g_strdup_printf("%.1f", (double)lastsize*2048/(1024*1024));
 
 	newrow = gtk_clist_append(GTK_CLIST(clist), text);
 	gtk_clist_set_row_data(GTK_CLIST(clist), newrow, info); 
 
+	g_free(text[1]);
 	free(path);
 }
 
-/* Add file to the (iso) file-list
- * if widget != 0, add the filepath contained in the file_selection data to
- *	the isofile clist
- * if widget == 0, add the path data to the isofile clist
- * TODO: go trough the clist and check if adding a duplicate entry */
-void selected_file(GtkWidget *widget, gpointer data) {
-	if (widget != 0) {
-		char *tmp;
-		GList *list;
-
-		dir_base = g_strdup(gtk_file_selection_get_filename(data));
-		if (NULL == (tmp = strrchr(dir_base, '/'))) {
-			g_warning("%s::%i: no / in path, this is a bug", __FILE__, __LINE__);
-			return;
-		}
-		tmp++;
-		*tmp = '\0';
-
-		cursor_wait(NULL);
-
-		list = (GTK_CLIST(GTK_FILE_SELECTION(data)->file_list))->selection;
-		if (NULL != list) {
-			g_list_foreach(list, add_path_to_iso_files,
-					(GTK_CLIST(GTK_FILE_SELECTION(data)->file_list)));
-		} else {
-			tmp--;
-			*tmp = '\0';
-			if (NULL == (tmp = strrchr(dir_base, '/'))) {
-				/* FIXME: adding /asdasd causes this to occur*/
-				g_warning("%s::%i: no / in path, this is probably a bug "
-						"(did you maybe add a non existant root dir?)",
-						__FILE__, __LINE__);
-				cursor_reset(NULL);
-				return;
-			}
-			tmp++;
-			*tmp = '\0';
-		}
-
-		list = (GTK_CLIST(GTK_FILE_SELECTION(data)->dir_list))->selection;
-		if (NULL != list)
-			g_list_foreach(list, add_path_to_iso_files,
-					(GTK_CLIST(GTK_FILE_SELECTION(data)->dir_list)));
-
-		free(dir_base);
-		dir_base = NULL;
-		gtk_clist_unselect_all(GTK_CLIST(GTK_FILE_SELECTION(data)->file_list));
-		gtk_clist_unselect_all(GTK_CLIST(GTK_FILE_SELECTION(data)->dir_list));
-		cursor_reset(NULL);
-	} else {
-		add_path_to_iso_files(data, NULL);
-	}
-
+static void path_added_update_gui(void) {
 	update_totalsize_label();
 	make_estimate_inaccurate();
 
-	resize_clist_col_ratio(NULL, NULL, clist);
-
 	mark_size_inaccurate();
 }
 
+/* Add file to the (iso) file-list */
+void add_path_to_files(char *file) {
+	add_path_to_iso_files(file);
+	path_added_update_gui();
+}
+
+static void add_path_from_list_to_iso_files(gpointer basename, gpointer dir_base) {
+	char *path;
+
+	path = g_strdup_printf("%s%s", (char *)dir_base, (char *)basename);
+	add_path_to_iso_files(path);
+	g_free(path);
+	g_free(basename);
+}
+
+static void add_path_to_file_list(gpointer row, gpointer clist) {
+	char *tmp;
+
+	gtk_clist_get_text(GTK_CLIST(clist), GPOINTER_TO_INT(row), 0, &tmp);
+	file_path_list = g_list_append(file_path_list, g_strdup(tmp));
+}
+
+static void add_path_to_dir_list(gpointer row, gpointer clist) {
+	char *tmp;
+
+	gtk_clist_get_text(GTK_CLIST(clist), GPOINTER_TO_INT(row), 0, &tmp);
+	dir_path_list = g_list_append(dir_path_list, g_strdup(tmp));
+}
+
+/* Add file to the (iso) file-list
+ * add the filepath contained in the file_selection data to the isofile clist
+ *
+ * The GTK+ file selector API does not provide a logical way to get the
+ * directory we are in, but the following should do it.  Also note that
+ * since about gtk+ 1.2.10, some Linux distributions changed the
+ * semantics of gtk_file_selection_set_filename, without changing the
+ * version number of gtk+. I knew the - so called - stable versions of
+ * gtk+ were a moving target to support, but now even the SAME version
+ * of gtk+ is a moving target. Keep up the good work!
+ *
+ * This function contains workarounds to the GTK+ problems, and workarounds to
+ * the bugs caused by the original workarounds. I have not found a workaround
+ * for saving/restoring the completions yet, so they are lost.
+ *
+ */
+void selected_file(GtkWidget *widget, gpointer sel) {
+	char *dir_base;
+	GtkAdjustment *adj;
+	gfloat file_adj_val, dir_adj_val;
+
+	cursor_wait();
+
+	gtk_clist_freeze(GTK_CLIST(GTK_FILE_SELECTION(sel)->file_list));
+	gtk_clist_freeze(GTK_CLIST(GTK_FILE_SELECTION(sel)->dir_list));
+
+	/* save the position the user has scrolled to (some of the following
+	 * calls reset it) */
+	adj = gtk_clist_get_vadjustment(GTK_CLIST(GTK_FILE_SELECTION(sel)->file_list));
+	file_adj_val = adj->value;
+	adj = gtk_clist_get_vadjustment(GTK_CLIST(GTK_FILE_SELECTION(sel)->dir_list));
+	dir_adj_val = adj->value;
+
+	/* copy the path names of the selected files (since they are cleared in
+	 * the next step) */
+	file_path_list = NULL;
+	dir_path_list = NULL;
+	if (NULL != (GTK_CLIST(GTK_FILE_SELECTION(sel)->file_list))->selection)
+		g_list_foreach((GTK_CLIST(GTK_FILE_SELECTION(sel)->file_list))->selection, add_path_to_file_list,
+				GTK_CLIST(GTK_FILE_SELECTION(sel)->file_list));
+	if (NULL != (GTK_CLIST(GTK_FILE_SELECTION(sel)->dir_list))->selection)
+		g_list_foreach((GTK_CLIST(GTK_FILE_SELECTION(sel)->dir_list))->selection, add_path_to_dir_list,
+				GTK_CLIST(GTK_FILE_SELECTION(sel)->dir_list));
+
+	/* then retrive the current directory (this also clears the completions
+	 * incase the user pressed tab => it must be done after we have made a
+	 * copy of the selected files above) */
+	gtk_file_selection_set_filename(GTK_FILE_SELECTION(sel), "");
+	dir_base = gtk_file_selection_get_filename(GTK_FILE_SELECTION(sel));
+
+	/* add the paths to the clist and deallocate the individual paths */
+	if (NULL != file_path_list)
+		g_list_foreach(file_path_list, add_path_from_list_to_iso_files, dir_base);
+	if (NULL != dir_path_list)
+		g_list_foreach(dir_path_list, add_path_from_list_to_iso_files, dir_base);
+
+	g_list_free(file_path_list);
+	g_list_free(dir_path_list);
+
+	/* reset to where the user was when he pressed OK */
+	adj = gtk_clist_get_vadjustment(GTK_CLIST(GTK_FILE_SELECTION(sel)->file_list));
+	gtk_adjustment_set_value(adj, file_adj_val);
+	adj = gtk_clist_get_vadjustment(GTK_CLIST(GTK_FILE_SELECTION(sel)->dir_list));
+	gtk_adjustment_set_value(adj, dir_adj_val);
+
+	gtk_clist_thaw(GTK_CLIST(GTK_FILE_SELECTION(sel)->file_list));
+	gtk_clist_thaw(GTK_CLIST(GTK_FILE_SELECTION(sel)->dir_list));
+
+	path_added_update_gui();
+
+	cursor_reset();
+}
+
 void del_selected_rows(GtkWidget *widget, gpointer data) {
 	file_data *info;
 	int i;
