@@ -57,33 +57,35 @@ static void check_multisession_button_data(GtkWidget *widget, gpointer *data) {
 void multisession_options(GtkWidget *vbox) {
 	GtkWidget *frame, *hbox, *label;
 
-	frame = make_frame(_("Multisession"), 5);
+	frame = make_frame(_("Multi Session"), 5);
 	gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, TRUE, 0);
 
 	hbox = gtk_hbox_new(FALSE, 0);
 	gtk_widget_show(hbox);
 	gtk_container_add(GTK_CONTAINER(frame), hbox);
 
-	enable_multisession = gtk_check_button_new_with_label(_("multisession"));
+	enable_multisession = gtk_check_button_new_with_label(_("multi session"));
 	gtk_widget_show(enable_multisession);
 	gtk_box_pack_start(GTK_BOX(hbox), enable_multisession, FALSE, FALSE, 0);
-	gtk_tooltips_set_tip(tooltips, enable_multisession, _("Make multisession image "
+	gtk_tooltips_set_tip(tooltips, enable_multisession, _("Make multi session image "
 				"(appends new image to old image) - first additional session "
 				"will waste about 22 MB, subsequent sessions about 13 MB in overhead. "
 				"NOTE: currently directories in the old sessions gets completely "
 				"overwritten when a new dir with the same name in a new session is "
 				"added (ie the files inside it not in the new session \"disappears\") "
-				"(some OSes allow you to mount individual sessions).\n"),
+				"(some OSes allow you to mount individual sessions).\n"
+				" * * * NOTE * * *\n"
+				"It seems like multisession doesn't work in gcombust at the moment!!!\n"),
 			NULL);
 
 	force_data_multisession = gtk_check_button_new_with_label(_("Use data"));
 	gtk_widget_show(force_data_multisession);
 	gtk_box_pack_start(GTK_BOX(hbox), force_data_multisession, FALSE, FALSE, 0);
 	gtk_tooltips_set_tip(tooltips, force_data_multisession, _("Some drives have "
-				"no hardware support for multisession type tracks, and this "
+				"no hardware support for multi session type tracks, and this "
 				"option needs to be enabled on those (this includes some "
 				"Sony drives). Currently you also have to enable this option "
-				"for making multisession disks in DAO/SAO mode."),
+				"for making multi session disks in DAO/SAO mode."),
 			NULL);
 	gtk_widget_set_sensitive(force_data_multisession, FALSE);
 
@@ -93,7 +95,7 @@ void multisession_options(GtkWidget *vbox) {
 	gtk_tooltips_set_tip(tooltips, enable_cdplus,  _("Make an image for CDplus. "
 				"The first session of CDplus consist of audio tracks and "
 				"the second session is a data track. When making a "
-				"multisession CD, mkisofs usually reads the directory "
+				"multi session CD, mkisofs usually reads the directory "
 				"structure from the previous session. This option "
 				"disables that (as audio tracks have no directory "
 				"structure)."), NULL); 
@@ -110,12 +112,12 @@ void multisession_options(GtkWidget *vbox) {
 
 #ifdef __FreeBSD__
 	gtk_tooltips_set_tip(tooltips, old_session, _("Path to old session image, usually "
-				"the drive where the multisession CD is (/dev/rcd0a), but can also "
+				"the drive where the multi session CD is (/dev/rcd0a), but can also "
 				"be an existing image on disk. Leave this empty for first session."),
 			NULL);
 #else
 	gtk_tooltips_set_tip(tooltips, old_session, _("Path to old session image, usually "
-				"the drive where the multisession CD is (/dev/hdb), but can also "
+				"the drive where the multi session CD is (/dev/hdb), but can also "
 				"be an existing image on disk. Leave this empty for first session."),
 			NULL);
 #endif
@@ -138,11 +140,9 @@ int check_blank_disk(void) {
 		if ((old_session_path) && (strlen(old_session_path) > 0)) {
 			int fd, res;
 
-			if (strlen(old_session_path) > 5) {
-				if (0 != strncmp("/dev/", old_session_path, 5)) {
-					/* old session not on a cdrom */
-					return 1;
-				}
+			if (0 != strncmp("/dev/", old_session_path, 5)) {
+				/* old session not on a cdrom */
+				return 1;
 			}
 
 			if (-1 == (fd = open(old_session_path, O_RDONLY | O_NONBLOCK))) {
@@ -163,7 +163,7 @@ int check_blank_disk(void) {
 			switch (res) {
 				case CDS_AUDIO:
 					alert_user_of_error(" The CDROM used as old session is an audio cd. \n"
-							" You MUST NOT perform multisession operations on audio cds. \n\n"
+							" You MUST NOT perform multi session operations on audio cds. \n\n"
 							" (This check can be turned off in the preferences) ");
 					return 0;
 					break;
@@ -194,11 +194,37 @@ int check_blank_disk(void) {
 	return 1;
 }
 
+/* This has nothing to do with multisession support, but the ioctl is in this
+ * file already... */
+int read_will_block_cd(int fd) {
+	int res;
+
+	res = ioctl(fd, CDROM_DISC_STATUS);
+
+	switch (res) {
+		case -1:
+		case CDS_DATA_1:
+		case CDS_DATA_2:
+		case CDS_XA_2_1:
+		case CDS_XA_2_2:
+		case CDS_MIXED:
+			return 0;
+		case CDS_AUDIO:
+		case CDS_NO_DISC:
+		case CDS_NO_INFO:
+		default:
+			return 1;
+	}
+}
+
 #else
 
 int check_blank_disk(void) {
 	return 1;
 }
 
+int read_will_block_cd(int fd) {
+	return 0;
+}
 #endif
 
