@@ -96,37 +96,44 @@ static void update_estimate_labels(long int size) {
  */
 
 static void begin_binpacking(GtkWidget *widget, gpointer data) {
-	file_data *sorted_info[MAX_ROWS];
-	file_data *to_mark_delete[MAX_ROWS];
-	file_data *check_these[MAX_ROWS];
+	file_data **sorted_info;
+	file_data **to_mark_delete;
+	file_data **check_these;
 	file_data *info;
-	int i, j, l, k;
+	int i, j;
 	cmd_v *cmd;
 	long int size_sofar = 150; /* cdrecord uses a few sectors for something
 				    * else, 150 is for 74m CDs */
 	long int old_session_size = get_old_session_size(mainptr->cdr_option_info);
 
+	sorted_info = g_malloc((GTK_CLIST(clist)->rows)*sizeof(file_data *));
+	to_mark_delete = g_malloc((GTK_CLIST(clist)->rows)*sizeof(file_data *));
+	check_these = g_malloc((GTK_CLIST(clist)->rows)*sizeof(file_data *));
+
+	if (NULL == sorted_info || NULL == to_mark_delete || NULL == check_these) {
+		g_free(sorted_info);
+		g_free(to_mark_delete);
+		g_free(check_these);
+		return;
+	}
+
 	size_sofar += old_session_size;
 
-	for (i = 0; i < MAX_ROWS; i++) { /* set up array to be sorted */
-		info = gtk_clist_get_row_data(GTK_CLIST(clist), i);
-		if (info == NULL)
-			break;
-		sorted_info[i] = info;
-	}
-	l = i;
-	for (i = 0; i < l; i++) { /* sort array */
+	for (i = 0; i < GTK_CLIST(clist)->rows; i++) /* set up array to be sorted */
+		sorted_info[i] = gtk_clist_get_row_data(GTK_CLIST(clist), i);
+
+	for (i = 0; i < GTK_CLIST(clist)->rows; i++) { /* sort array */
 		info = sorted_info[i];
 		for (j = i; (j > 0) && (sorted_info[j-1]->size > info->size); j--)
 			sorted_info[j] = sorted_info[j-1];
 		sorted_info[j] = info;
 	}
 	if (GTK_TOGGLE_BUTTON(opt_try_harder)->active) { /* first fit decreasing */
+		int k;
 		j = 0;
 		k = 0;
-		l = GTK_CLIST(clist)->rows;
 		mainwindow_disable_tabs();
-		for (i = l - 1; i >= 0; i--) {
+		for (i = GTK_CLIST(clist)->rows - 1; i >= 0; i--) {
 			check_these[k] = sorted_info[i];
 			if (NULL == (cmd = make_mkisofs_c_optimize(check_these, k+1)))
 				continue;
@@ -142,20 +149,25 @@ static void begin_binpacking(GtkWidget *widget, gpointer data) {
 				to_mark_delete[j++] = sorted_info[i];
 		}
 		mainwindow_enable_tabs();
-		if (NULL == (cmd = make_mkisofs_c_optimize(check_these, k))) {
-			g_warning("optimize_usage.c::begin_bin_packing: Could not "
-					"recheck pack result, estimate size will not be updated!");
-			return;
+		if (k > 0) {
+			if (NULL == (cmd = make_mkisofs_c_optimize(check_these, k))) {
+				g_warning("optimize_usage.c::begin_bin_packing: Could not "
+						"recheck pack result, estimate size will not be updated!");
+				g_free(sorted_info);
+				g_free(to_mark_delete);
+				g_free(check_these);
+				return;
+			}
+			sectorsize = 150 + old_session_size;
+			if (!(is_running())) {
+				execute_recalc_size(cmd);
+				not_running();
+			}
+			size_sofar = sectorsize;
 		}
-		sectorsize = 150 + old_session_size;
-		if (!(is_running())) {
-			execute_recalc_size(cmd);
-			not_running();
-		}
-		size_sofar = sectorsize;
 	} else { /* fast sort using "cached" size data */
 		j = 0;
-		for (i = l - 1; i >= 0; i--) {
+		for (i = GTK_CLIST(clist)->rows - 1; i >= 0; i--) {
 			if (size_sofar + sorted_info[i]->size < opt_cdsize)
 				size_sofar += sorted_info[i]->size;
 			else
@@ -166,12 +178,20 @@ static void begin_binpacking(GtkWidget *widget, gpointer data) {
 	update_estimate_labels(size_sofar);
 	make_estimate_accurate();
 	select_to_be_deleted(to_mark_delete, j);
+
+	g_free(sorted_info);
+	g_free(to_mark_delete);
+	g_free(check_these);
 }
 
 static void set_cd_size(long int sectsize) {
 	/* FIXME: magic constant that could fail with NLS support if some language
 	 * has long words */
 	char s[50];
+
+	if (opt_cdsize != sectsize)
+		make_estimate_inaccurate();
+
 	opt_cdsize = sectsize;
 
 	if (-1 == g_snprintf(s, 50, _("Sectors: %ld"), sectsize))
@@ -181,8 +201,6 @@ static void set_cd_size(long int sectsize) {
 	if (-1 == g_snprintf(s, 50, _("Size: %ld MB"), (sectsize*2048)/(1024*1024)))
 		g_warning("optimize_usage.c::set_cd_size: g_snprintf returned -1!");
 	gtk_label_set(GTK_LABEL(cdsize_selected_label), s);
-
-	begin_binpacking(NULL, NULL);
 }
 
 static gint size_selection_74(GtkWidget *widget, gpointer data) {
@@ -195,14 +213,19 @@ static gint size_selection_80(GtkWidget *widget, gpointer data) {
 	return FALSE;
 }
 
+static gint size_selection_dvd(GtkWidget *widget, gpointer data) {
+	set_cd_size(2298300);
+	return FALSE;
+}
+
 static gint size_selection_atip(GtkWidget *widget, gpointer data) {
 	cmd_v *cdr_cmd;
 	char *start;
 	FILE *f;
 	int done = 0;
 	long int atip_size = 0;
-      char in_buf[BUF_S];
-	
+	char in_buf[BUF_S];
+
 	cdr_cmd = make_cdrecord_read_atip_command(mainptr->cdr_option_info);
 	if (NULL == (f = popen_r_stdout(cdr_cmd))) {
 		g_warning("%s::%i: popen failed", __FILE__, __LINE__);
@@ -224,6 +247,9 @@ static gint size_selection_atip(GtkWidget *widget, gpointer data) {
 			} else if ((start = strstr(in_buf, "ATIP start of lead out:"))) {
 				atip_size = atol(start + 23);
 				done = 1;
+			} else if ((start = strstr(in_buf,"free blocks:"))) {
+				atip_size = atol(start + 13);
+				done = 1;
 			}
 		} else {
 			g_warning("%s::%i: error executing cdrecord ATIP command",
@@ -260,7 +286,7 @@ static gint size_selection_user(GtkWidget *widget, gpointer data) {
 	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(cd_size_dialog)->vbox),
 			entry, FALSE, FALSE, 0);
 	gtk_tooltips_set_tip(tooltips, entry, _("Enter the size of your "
-			"cd-r (for example 340000)"), NULL);
+			"CD-R (e.g., 340000)/DVD-R (e.g., 2298000)"), NULL);
 
 	button = gtk_button_new_with_label(_("Make it so"));
 	gtk_widget_show(button);
@@ -324,6 +350,12 @@ void optimize_attach(GtkWidget *vbox) {
 	gtk_signal_connect(GTK_OBJECT(menuitem), "button_release_event",
 			GTK_SIGNAL_FUNC(size_selection_80), NULL);
 
+	menuitem = gtk_menu_item_new_with_label(_("DVD-R"));
+	gtk_widget_show(menuitem);
+	gtk_menu_append(GTK_MENU(cdsize_option_menu), menuitem);
+	gtk_signal_connect(GTK_OBJECT(menuitem), "button_release_event",
+			GTK_SIGNAL_FUNC(size_selection_dvd), NULL);
+
 	menuitem = gtk_menu_item_new_with_label(_("disc"));
 	gtk_widget_show(menuitem);
 	gtk_menu_append(GTK_MENU(cdsize_option_menu), menuitem);
