@@ -39,8 +39,8 @@
 
 /* TODO: path and version check */
 
-GtkWidget *prefs_speed_spin;
-misc_preferences misc_prefs = { TRUE, TRUE, TRUE, FALSE, FALSE, TRUE, FALSE, TRUE, FALSE, FALSE, TRUE, NULL};
+static GtkWidget *prefs_speed_spin, *prefs_grace_time_spin;
+misc_preferences misc_prefs = { TRUE, TRUE, TRUE, FALSE, FALSE, TRUE, FALSE, TRUE, FALSE, FALSE, TRUE, FALSE, NULL};
 static GtkWidget *mkisofs_path_entry, *diff_path_entry;
 static GtkWidget *cdrecord_path_entry, *cdlabelgen_path_entry, *cdda2wav_path_entry;
 static GtkWidget *lpr_path_entry, *cdparanoia_path_entry;;
@@ -49,7 +49,7 @@ static GtkWidget *prefs_eject, *iso_location_entry, *rip_location_entry, *fifo_e
 static GtkWidget *prefs_set_multisession, *prefs_old_session, *prefs_do_ms_check;
 static GtkWidget *selection_location_entry, *cddadev_entry, *isodev_entry;
 static GtkWidget *prefs_get_size, *prefs_beep, *prefs_burnproof, *prefs_disable_fixate;
-static GtkWidget *prefs_completion_msg;
+static GtkWidget *prefs_completion_msg, *prefs_overburn;
 static config_cdr_data *prefs_cdr_info = NULL;
 
 static void new_mkisofs_path(GtkWidget *widget, gpointer data) {
@@ -243,7 +243,7 @@ static GtkWidget *add_paths_page(void) {
 			(GtkAttachOptions) GTK_FILL,
 			(GtkAttachOptions) GTK_FILL, 0, 0);
 
-	gtk_tooltips_set_tip(tooltips, button11, _("Open up filerequester "
+	gtk_tooltips_set_tip(tooltips, button11, _("Open up file requester "
 				"and set the path to the lpr program "
 				"(eg /usr/bin/lpr). Another method for printing "
 				"can also be use (e.g. pdq)."), NULL);
@@ -304,7 +304,7 @@ static GtkWidget *add_devices_page(void) {
 	gtk_box_pack_start(GTK_BOX(hbox), swab_audio, TRUE, TRUE, 0);
 	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(swab_audio),
 			GTK_TOGGLE_BUTTON(mainptr->cdr_option_info->swab_audio)->active ? 1 : 0);
-	gtk_tooltips_set_tip(tooltips, swab_audio, _("Asume audio data is in byte-swapped "
+	gtk_tooltips_set_tip(tooltips, swab_audio, _("Assume audio data is in byte-swapped "
 			"(little-endian) order"), NULL);
 	prefs_cdr_info->swab_audio = swab_audio;
 
@@ -313,6 +313,11 @@ static GtkWidget *add_devices_page(void) {
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(prefs_speed_spin),
 			gtk_spin_button_get_value_as_float(GTK_SPIN_BUTTON(speed_spin)));
 
+	prefs_grace_time_spin = select_grace_time(hbox);
+
+	gtk_spin_button_set_value(GTK_SPIN_BUTTON(prefs_grace_time_spin),
+			gtk_spin_button_get_value_as_float(GTK_SPIN_BUTTON(grace_time_spin)));
+
 	hbox = gtk_hbox_new(FALSE, 0);
 	gtk_widget_show(hbox);
 	gtk_box_pack_start(GTK_BOX(vbox), hbox, TRUE, TRUE, 0);
@@ -378,17 +383,17 @@ static GtkWidget *add_misc_page(void) {
 	gtk_widget_show(table);
 	gtk_container_add(GTK_CONTAINER(frame), table);
 
-	prefs_enable_tooltips = gtk_check_button_new_with_label(_("Enable tooltips"));
+	prefs_enable_tooltips = gtk_check_button_new_with_label(_("Enable tool tips"));
 	gtk_widget_show(prefs_enable_tooltips);
 	gtk_tooltips_set_tip(tooltips, prefs_enable_tooltips,
-			_("Toggles display of all tooltips"), NULL);	
+			_("Toggles display of all tool tips"), NULL);	
 	gtk_table_attach(GTK_TABLE(table), prefs_enable_tooltips, 0, 1, 0, 1,
 			GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
 
-	prefs_own_progresswin = gtk_check_button_new_with_label(_("Progressbar has own window"));
+	prefs_own_progresswin = gtk_check_button_new_with_label(_("Progress bar has own window"));
 	gtk_widget_show(prefs_own_progresswin);
 	gtk_tooltips_set_tip(tooltips, prefs_own_progresswin,
-			_("If disabled the progressinfo-widget is created as a child to the mainwindow, "
+			_("If disabled the progress-info-widget is created as a child to the main window, "
 				"and not in a window of it's own"), NULL);	
 	gtk_table_attach(GTK_TABLE(table), prefs_own_progresswin, 1, 2, 0, 1,
 			GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
@@ -396,29 +401,29 @@ static GtkWidget *add_misc_page(void) {
 	prefs_dummy = gtk_check_button_new_with_label(_("Dummy enabled by default"));
 	gtk_widget_show(prefs_dummy);
 	gtk_tooltips_set_tip(tooltips, prefs_dummy,
-			_("Have the dummy run checkbox ticked when starting gcombust."), NULL);	
+			_("Have the dummy run check box ticked when starting gcombust."), NULL);	
 	gtk_table_attach(GTK_TABLE(table), prefs_dummy, 0, 1, 1, 2,
 			GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
 
 	prefs_eject = gtk_check_button_new_with_label(_("Eject target enabled by default"));
 	gtk_widget_show(prefs_eject);
 	gtk_tooltips_set_tip(tooltips, prefs_eject,
-			_("Have the eject target checkbox ticked when starting gcombust."), NULL);	
+			_("Have the eject target check box ticked when starting gcombust."), NULL);	
 	gtk_table_attach(GTK_TABLE(table), prefs_eject, 1, 2, 1, 2,
 			GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
 
 	prefs_set_multisession =
-		gtk_check_button_new_with_label(_("Multisession enabled by default"));
+		gtk_check_button_new_with_label(_("Multi Session enabled by default"));
 	gtk_widget_show(prefs_set_multisession);
 	gtk_tooltips_set_tip(tooltips, prefs_set_multisession,
-			_("Have the multisession run checkbox ticked when starting gcombust."), NULL);
+			_("Have the multi session run check box ticked when starting gcombust."), NULL);
 	gtk_table_attach(GTK_TABLE(table), prefs_set_multisession, 0, 1, 2, 3,
 			GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
 
-	prefs_do_ms_check = gtk_check_button_new_with_label(_("Validate multisession disks"));
+	prefs_do_ms_check = gtk_check_button_new_with_label(_("Validate multi session disks"));
 	gtk_widget_show(prefs_do_ms_check);
 	gtk_tooltips_set_tip(tooltips, prefs_do_ms_check,
-			_("When performing multisession operations, try to check that the CD "
+			_("When performing multi session operations, try to check that the CD "
 				"containing the old session is correct (not available on all "
 				"platforms)."),
 			NULL);	
@@ -428,7 +433,7 @@ static GtkWidget *add_misc_page(void) {
 	prefs_get_size = gtk_check_button_new_with_label(_("Get size enabled by default"));
 	gtk_widget_show(prefs_get_size);
 	gtk_tooltips_set_tip(tooltips, prefs_get_size,
-			_("Have the \"get size\" checkbox ticked when starting gcombust."), NULL);	
+			_("Have the \"get size\" check box ticked when starting gcombust."), NULL);	
 	gtk_table_attach(GTK_TABLE(table), prefs_get_size, 0, 1, 3, 4,
 			GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
 
@@ -442,14 +447,14 @@ static GtkWidget *add_misc_page(void) {
 	prefs_burnproof = gtk_check_button_new_with_label(_("Burnproof"));
 	gtk_widget_show(prefs_burnproof);
 	gtk_tooltips_set_tip(tooltips, prefs_burnproof,
-			_("Have the \"Burnproof\" checkbox ticked when starting gcombust."), NULL);	
+			_("Have the \"Burnproof\" check box ticked when starting gcombust."), NULL);	
 	gtk_table_attach(GTK_TABLE(table), prefs_burnproof, 0, 1, 4, 5,
 			GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
 
 	prefs_disable_fixate = gtk_check_button_new_with_label(_("Disable fixate"));
 	gtk_widget_show(prefs_disable_fixate);
 	gtk_tooltips_set_tip(tooltips, prefs_disable_fixate,
-			_("Have the \"Disable fixate\" checkbox ticked when starting gcombust."), NULL);	
+			_("Have the \"Disable fixate\" check box ticked when starting gcombust."), NULL);	
 	gtk_table_attach(GTK_TABLE(table), prefs_disable_fixate, 1, 2, 4, 5,
 			GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
 
@@ -472,6 +477,13 @@ static GtkWidget *add_misc_page(void) {
 	gtk_table_attach(GTK_TABLE(table), prefs_completion_msg, 0, 1, 6, 7,
 			GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
 
+	prefs_overburn = gtk_check_button_new_with_label(_("Overburn"));
+	gtk_widget_show(prefs_overburn);
+	gtk_tooltips_set_tip(tooltips, prefs_overburn,
+			_("Have the overburn button enabled by default"), NULL);	
+	gtk_table_attach(GTK_TABLE(table), prefs_overburn, 1, 2, 6, 7,
+			GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
+
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(prefs_enable_tooltips),
 			misc_prefs.enable_tooltips);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(prefs_own_progresswin),
@@ -487,6 +499,7 @@ static GtkWidget *add_misc_page(void) {
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(prefs_burnproof), misc_prefs.burnproof);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(prefs_disable_fixate), misc_prefs.disable_fixate);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(prefs_completion_msg), misc_prefs.completion_msg);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(prefs_overburn), misc_prefs.overburn);
 	if (NULL != misc_prefs.old_session)
 		gtk_entry_set_text(GTK_ENTRY(prefs_old_session), misc_prefs.old_session);
 
@@ -610,8 +623,6 @@ static int destroy_prefs_win(GtkWidget *widget, gpointer data) {
 static void forget_changes(GtkWidget *widget, gpointer data) {
 	gtk_widget_destroy(GTK_WIDGET(data));
 
-	check_all_paths_set();
-
 	destroy_prefs_win(NULL, 0);
 }
 
@@ -676,6 +687,7 @@ void apply_misc_changes(void) {
 	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(need_track_size), misc_prefs.get_size);
 	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(enable_burnproof), misc_prefs.burnproof);
 	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(disable_fixate), misc_prefs.disable_fixate);
+	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(overburn), misc_prefs.overburn);
 }
 
 static void accept_misc_changes(void) {
@@ -690,6 +702,7 @@ static void accept_misc_changes(void) {
 	misc_prefs.burnproof = GTK_TOGGLE_BUTTON(prefs_burnproof)->active;
 	misc_prefs.disable_fixate = GTK_TOGGLE_BUTTON(prefs_disable_fixate)->active;
 	misc_prefs.completion_msg = GTK_TOGGLE_BUTTON(prefs_completion_msg)->active;
+	misc_prefs.overburn = GTK_TOGGLE_BUTTON(prefs_overburn)->active;
 
 	if (NULL != misc_prefs.old_session)
 		g_free(misc_prefs.old_session);
@@ -724,6 +737,9 @@ static void accept_scsi_changes(void) {
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(speed_spin),
 			gtk_spin_button_get_value_as_float(GTK_SPIN_BUTTON(prefs_speed_spin)));
 
+	gtk_spin_button_set_value(GTK_SPIN_BUTTON(grace_time_spin),
+			gtk_spin_button_get_value_as_float(GTK_SPIN_BUTTON(prefs_grace_time_spin)));
+
 	gtk_entry_set_text(GTK_ENTRY(mainptr->cdr_option_info->fifo),
 			gtk_entry_get_text(GTK_ENTRY(prefs_cdr_info->fifo)));
 
