@@ -120,7 +120,7 @@ void set_mb_fifo_info(char *mb_fifo) {
 	}
 	/* FIXME: better check here or before calling it; on errors the error message
 	 *        gets appended to the mb_info */
-	mb_fifo[strlen(mb_fifo) - 2] = 0; /* don't want the trailing . */
+	mb_fifo[strlen(mb_fifo) - 2] = ' '; /* don't want the trailing . */
 	gtk_label_set(GTK_LABEL(fifo_label), mb_fifo);
 }
 
