@@ -19,6 +19,7 @@
 #include <gtk/gtk.h>
 #include <stdio.h>
 #include <string.h>
+#include <errno.h>
 
 #include "selection_IO.h"
 #include "common_gtk.h"
@@ -61,8 +62,8 @@ void save_selection(char *save_to_filename, int type) {
 	char *keyword;
 
 	if (NULL == (out_file = fopen(save_to_filename, "w"))) {
-		g_warning("select_IO.c::save_selection: fopen() of %s failed",
-				save_to_filename);
+		g_warning("select_IO.c::save_selection:%d fopen() of %s failed",
+				__LINE__, save_to_filename);
 		return;
 	}
 
@@ -71,18 +72,18 @@ void save_selection(char *save_to_filename, int type) {
 			fclist = clist;
 			keyword = "iso_sel_path=";
 			if (EOF == fputs(SEL_TYPE_ISO, out_file))
-				g_warning("selection_IO.c::save_selection: fputs() failed");
+				g_warning("selection_IO.c::save_selection:%d fputs() failed", __LINE__);
 			break;
 		case 1:
 			fclist = audio_clist;
 			keyword = "audio_sel_path=";
 			if (EOF == fputs(SEL_TYPE_AUDIO, out_file))
-				g_warning("selection_IO.c::save_selection: fputs() failed");
+				g_warning("selection_IO.c::save_selection:%d fputs() failed", __LINE__);
 			break;
 		default:
 			g_warning("selection_IO.c::save_selection: type not implemented");
 			if (EOF == fclose(out_file))
-				g_warning("selection_IO.c::save_selection: fclose() failed");
+				g_warning("selection_IO.c::save_selection:%d fclose() failed", __LINE__);
 			return;
 	}
 
@@ -90,22 +91,22 @@ void save_selection(char *save_to_filename, int type) {
 		info = gtk_clist_get_row_data(GTK_CLIST(fclist), i);
 		g_assert(NULL != info);
 		if (EOF == fputs(keyword, out_file))
-			g_warning("selection_IO.c::save_selection: fputs() failed");
+			g_warning("selection_IO.c::save_selection:%d fputs() failed", __LINE__);
 		if (EOF == fputs(info->realpath, out_file))
-			g_warning("selection_IO.c::save_selection: fputs() failed");
+			g_warning("selection_IO.c::save_selection:%d fputs() failed", __LINE__);
 		if (0 == type) {
 			if (EOF == fputs("\n", out_file))
-				g_warning("selection_IO.c::save_selection: fputs() failed");
+				g_warning("selection_IO.c::save_selection:%d fputs() failed", __LINE__);
 			if (EOF == fputs("iso_sel_user=", out_file))
-				g_warning("selection_IO.c::save_selection: fputs() failed");
+				g_warning("selection_IO.c::save_selection:%d fputs() failed", __LINE__);
 			if (EOF == fputs(info->userpath, out_file))
-				g_warning("selection_IO.c::save_selection: fputs() failed");
+				g_warning("selection_IO.c::save_selection:%d fputs() failed", __LINE__);
 		}
 		if (EOF == fputs("\n", out_file))
-			g_warning("selection_IO.c::save_selection: fputs() failed");
+			g_warning("selection_IO.c::save_selection:%d fputs() failed", __LINE__);
 	}
 	if (EOF == fclose(out_file))
-		g_warning("selection_IO.c::save_selection: fclose() failed");
+		g_warning("selection_IO.c::save_selection:%d fclose() failed", __LINE__);
 }
 
 /* loads selection from file, auto determines type
@@ -117,14 +118,13 @@ void load_selection(char *load_from_filename) {
 	FILE *in_file;
 
 	if (NULL == (in_file = fopen(load_from_filename, "r"))) {
-		g_warning("seleciont_IO.c::load_selection: fopen() of %s failed",
-				load_from_filename);
+		g_warning("%s:%d fopen() of %s failed",
+				__FILE__, __LINE__, load_from_filename);
 		return;
 	}
 
 	if (NULL == fgets(buffer, BUF_S, in_file))
-		g_warning("selection_IO.c::load_selection: fgets() failed");
-
+		g_warning("%s:%d fgets() failed", __FILE__, __LINE__);
 	if (!strcmp(buffer, SEL_TYPE_ISO)) {
 		gtk_clist_clear(GTK_CLIST(clist));
 
@@ -132,7 +132,7 @@ void load_selection(char *load_from_filename) {
 		while (NULL != fgets(buffer, BUF_S, in_file)) {
 			if (!strncmp(buffer, "iso_sel_path=", strlen("iso_sel_path="))) {
 				buffer[strlen(buffer)-1] = '\0';
-				selected_file(0, buffer + strlen("iso_sel_path="));
+				add_path_to_files(buffer + strlen("iso_sel_path="));
 			} else if (!strncmp(buffer, "iso_sel_user=", strlen("iso_sel_user="))) {
 				file_data *selected_row_info;
 
@@ -160,13 +160,12 @@ void load_selection(char *load_from_filename) {
 			}
 		}
 	} else {
-		g_warning("selection_IO.c::load_selection: file format not implemented");
-		if (EOF == fclose(in_file))
-			g_warning("selection_IO.c::load_selection: fclose() failed");
-		return;
+		g_warning("%s:%d file format not implemented", __FILE__, __LINE__);
 	}
 
-	if (EOF == fclose(in_file))
-		g_warning("selection_IO.c::load_selection: fclose() failed");
+	if (EOF == fclose(in_file)) {
+		g_warning("%s:%d fclose() failed", __FILE__, __LINE__);
+		printf("%s\n", strerror(errno));
+	}
 }
 
