@@ -22,7 +22,9 @@ typedef struct {
 	char **elements;
 } cmd_v;
 
-void add_option_to_cmd(cmd_v *, char *);
+void add_option_to_cmd(cmd_v *, const char *);
 void destroy_cmd(cmd_v *);
 cmd_v *get_new_cmd(void);
 void print_cmd(cmd_v *);
+char *cmd_to_string(cmd_v *);
+char *escape_graft_chars(const char *);
